@@ -6,6 +6,8 @@ import pytz
 import requests
 import time
 
+from django.core.paginator import Paginator
+from django.db.models import F
 from django.forms import model_to_dict
 from django.utils import timezone
 from pathlib import Path
@@ -27,9 +29,59 @@ main_config_dict = JDict(JConfig.get_section(path=str(BASE_DIR) + "/config.ini",
 module_config_dict = JDict(JConfig.get_section(path=str(BASE_DIR) + "/config.ini", section="xj_payment"))
 
 sub_appid = main_config_dict.wechat_merchant_app_id or module_config_dict.wechat_merchant_app_id or ""
+# 商户名称
+merchant_name = main_config_dict.merchant_name or module_config_dict.merchant_name or ""
 
 
 class PaymentService:
+    @staticmethod
+    def get(params):
+        limit = params.pop('limit', 20)
+        page = params.pop('page', 20)
+        list_obj = PaymentPayment.objects.filter(**params)
+        count = list_obj.count()
+        list_obj = list_obj.values(
+            "id",
+            "transact_no",
+            "order_no",
+            "transact_id",
+            "enroll_id",
+            "order_id",
+            "user_id",
+            "subject",
+            "total_amount",
+            "buyer_pay_amount",
+            "point_amount",
+            "invoice_amount",
+            "price_off_amount",
+            "pay_mode",
+            "order_status_id",
+            "payment_status_id",
+            "nonce_str",
+            "order_time",
+            "create_time",
+            "modify_time",
+            "payment_time",
+            "refunt_time",
+            "close_time",
+            "voucher_detail",
+            "snapshot",
+            "more",
+
+        ).annotate(payment_status=F('payment_status__payment_status'), )
+        res_set = Paginator(list_obj, limit).get_page(page)
+        page_list = []
+        if res_set:
+            page_list = list(res_set.object_list)
+        for v in page_list:
+            v['total_amount'] = int(v['total_amount']) / 100
+            v['point_amount'] = int(v['point_amount']) / 100
+            v['buyer_pay_amount'] = int(v['buyer_pay_amount']) / 100
+            v['invoice_amount'] = int(v['invoice_amount']) / 100
+            v['price_off_amount'] = int(v['price_off_amount']) / 100
+
+        return {'count': count, 'page': page, 'limit': limit, "list": page_list}, None
+
     # 支付总接口
     @staticmethod
     def pay(params):
@@ -67,7 +119,7 @@ class PaymentService:
             "total_amount": int(data['total_fee']),
             "create_time": now,
         }
-        data['platform'] = 'muzpay'
+        data['platform'] = merchant_name
         data['currency'] = 'CNY'
 
         if params.get("total_amount", 0):
