@@ -15,6 +15,7 @@ from main.settings import BASE_DIR
 from xj_enroll.service.enroll_services import EnrollServices
 from xj_finance.services.finance_service import FinanceService
 from xj_finance.services.finance_transact_service import FinanceTransactService
+from xj_finance.services.finance_transacts_service import FinanceTransactsService
 from xj_thread.services.thread_item_service import ThreadItemService
 from xj_user.services.user_service import UserService
 from ..models import PaymentPayment
@@ -367,9 +368,9 @@ class PaymentWechatService:
                 transaction_id = param['transaction_id']  # 微信支付订单号
             finance_data = {
                 "order_no": out_trade_no,
-                "transact_id": transaction_id,
+                "transact_id": transaction_id + "-1",
                 "their_account_name": sub_appid,
-                "platform": "muzpay",
+                "platform": merchant_name,
                 "amount": float("-" + str(total_amount)),
                 "currency": "CNY",
                 "pay_mode": "WECHAT",
@@ -384,7 +385,6 @@ class PaymentWechatService:
             # 根据支付记录用户 查询用户基本信息
             user_set, err = UserService.user_basic_message(payment_message['user_id'])
             user_platform_set, platform_err = UserService.user_basic_message(nickname=sub_appid)
-
             # 用户报名通知代码块
             if user_set:
                 if payment_message['enroll_id']:
@@ -395,8 +395,8 @@ class PaymentWechatService:
                         thread_set, thread_err = ThreadItemService.detail(enroll_set['thread_id'])
                         if thread_set:
                             project_name = thread_set['title']
-                summary = "【" + user_set['full_name'] + "】支付 【" + user_platform_set[
-                    'full_name'] + "】项目名称【" + project_name + "】款项"
+            summary = "【" + user_set['full_name'] + "】支付 【" + user_platform_set[
+                'full_name'] + "】项目名称【" + project_name + "】款项"
 
             finance_data['summary'] = summary
             # # TODO 拿到订单号后的操作 看自己的业务需求
@@ -406,20 +406,25 @@ class PaymentWechatService:
                 logging.debug(">>>>payment_logic_processing" + "写入资金模块失败（用户支付）")
                 raise Networkerror("Bad hostname")
             # 根据唯一交易id 查询主键id
-            finance_data, err = FinanceTransactService.finance_transact_detailed(transaction_id)
+            finance_data, err = FinanceTransactService.finance_transact_detailed(transaction_id + "-1")
             if finance_data:
                 finance_data = model_to_dict(finance_data)
                 payment_data = {
                     "transact_no": transaction_id,
                     "transact_id": finance_data['id'],
+                    "payment_status": 1,
+                    "pay_mode": "WECHAT",
                     "order_status_id": "24"
+
                 }
                 # （平台收入）
                 platform_revenue_data = {
+                    "order_no": out_trade_no,
+                    "transact_id": transaction_id + "-2",
                     "account_id": finance_data['their_account'],
                     "their_account_id": finance_data['account'],
                     "enroll_id": finance_data['enroll_id'],
-                    "platform": "muzpay",
+                    "platform": merchant_name,
                     "amount": float(total_amount),
                     "summary": "【" + user_set['full_name'] + "】支付 【" + user_platform_set[
                         'full_name'] + "】项目名称【" + project_name + "】款项",
@@ -433,12 +438,14 @@ class PaymentWechatService:
                 # 更改支付记录
                 PaymentPayment.objects.filter(order_no=int(out_trade_no)).update(**payment_data)
                 # 报名表支付状态修改
-                EnrollServices.pay_call_back(out_trade_no)
+                pay_call_back_data, pay_call_back_err = EnrollServices.pay_call_back(out_trade_no)
+                if pay_call_back_err:
+                    logging.debug(">>>>报名修改失败" + pay_call_back_err)
 
         except Networkerror as t:
-            print("支付回调异常：", t)
+            print("支付回调异常1：", t)
             transaction.savepoint_rollback(sid)
         except Exception as e:
-            print("支付回调异常：", e)
+            print("支付回调异常2：", e)
             transaction.savepoint_rollback(sid)
             logging.debug("payment_logic_processing" + e)
